[![Build Status](https://travis-ci.org/tingelst/tpk4170-robotics.svg?branch=master)](https://travis-ci.org/tingelst/tpk4170-robotics)

# TPK4170 Robotics

Python code accompanying the course TPK4170 Robotics at the Department of Mechanical and Industrial Engineering (MTP) at the Norwegian University of Science and Technology (NTNU), Trondheim, Norway.

## Installation

```bash
pip install https://github.com/tingelst/tpk4170-robotics/archive/master.zip
```
